package com.devexperts.mdd.auth.entitle;

import com.dxfeed.api.DXEndpoint;
import com.dxfeed.api.DXFeedSubscription;
import com.dxfeed.event.market.Quote;

/**
 * Sample client that demonstrates usage of {@link EntitleLoginHandlerFactory}.
 * In order to run the client, in addition to dxfeed-api and qds libraries,
 * auther-api.jar must be added to classpath (it adds factory using META-INF/services support.)
 */
public class SampleClient {

    private static final String TASTY_ISSUER = "tasty";
    private static final String DEMO_SESSION = "demo";
    private static final String USER = "603f7fcc-27dc-45e9-b533-776ff6f99ce7";
    private static final String SECRET = "0123456789";

    public static void main(String[] args) throws Exception {
        // Should be received from the external auth server where the user authenticates
        String token = EntitleLoginHandlerFactory.createToken(TASTY_ISSUER, DEMO_SESSION, USER, SECRET);
        System.out.println("Signed token: " + token);

        // Specify token in the connection string
        String address = "127.0.0.1:7501[login=entitle:" + token + "]";
        // Or (preferably) set global variable and use shorter connection string
        //AutherLoginHandlerFactory.setAppToken(token);
        //address = "127.0.0.1:7501[login=entitle]";

        // Sample endpoint
        DXEndpoint endpoint = DXEndpoint.newBuilder()
            .withName("sample")
            .withRole(DXEndpoint.Role.FEED)
            .build();
        endpoint.connect(address);

        // Sample subscription
        DXFeedSubscription<Quote> sub = endpoint.getFeed().createSubscription(Quote.class);
        sub.addEventListener(events -> events.forEach(System.out::println));
        sub.addSymbols("IBM", "GOOG", "AAPL");

        System.out.println("Press <Enter> to stop...");
        System.in.read();
    }
}
